## Introduction
Digital technology provides many innovative tools for teaching and learning, including powerful open-source software and virtual spaces to collaborate and share documents. We see these as real opportunities to develop and provide learning materials with which students can get more deeply involved in science. In particular, Jupyter Notebook (https://jupyter.org/) offers a versatile framework for producing scientific worksheets, course modules [1], or open reproducible papers [2, 3]. A rich gallery of examples is available at the Jupyter wiki (https://github.com/jupyter/jupyter/wiki). Many collections of Jupyter notebooks are hosted in GitHub (https://github.com/). Open notebooks available publicly concerning topics in physics are mostly on advanced topics, whereas we wanted to exploit the features of the Jupyter Project at a beginner level, with emphasis on practical aspects, experiments, and a hands-on approach.

[**Simple Physics with Python**](http://github.com/POSS-UniMe/simple-physics-with-Python) is the name of a collection, hosted in a GitHub repository, in which we present a set of Jupyter notebooks on elementary mechanics [4]. They cover topics in kinematics and are grouped in chapters concerning one-dimensional motion, two-dimensional motion, and support topics, respectively. A further chapter contains notebooks on slightly more advanced examples.

Each notebook begins with the statement of a physics problem, connected to a real situation. Then we discuss the problem in a wider context and propose a model, along with equations involving relevant variables. Finally, we use simple Python code to calculate and visualize the results.

We proposed this material as workbooks for courses in general physics for majors in Computer Science, Information Technology, and Data Science. It also would fit well in an introductory physics course for undergraduate students in Science and Engineering.

## Concepts
Through our digital workbooks we want to convey some fundamental messages to users, and focus on some key aspects.

### Physics is not just equations
For each problem, we propose a model of a physical phenomenon, so that we can describe what happens with suitable detail, and possibly make reliable predictions. For example, we can compute the position of an object as a function of time, and the instantaneous values of velocity and acceleration. We discuss the case of [projectile motion](https://nbviewer.org/github/POSS-UniMe/simple-physics-with-Python/blob/main/Chapter02/Section01/2-1-3-ProjectileMotionSimulation.ipynb), in which we can draw the provisional trajectory, given the initial velocity and the initial angle with which the object is launched. We can easily observe what happens on varying the initial angles, i.e., drawing many possible trajectories, so we discover that an entire region could never be reached by the object under the given initial conditions.

### Results are not just numbers
Everybody knows, more or less, how tall they are, what is their weight, or how much they should pay for a sandwich. It would be great if participating in a physics course one could learn to know what is roughly the expected value of some physical variables, so as to judge whether the results of an analysis are reasonable. In almost every notebook we include a section entitled *Get a feel of*, in which we try to make the reader enter in closer contact with the problem discussed and think about the values of the relevant variables. To this aim, we also make comparisons with well-known examples: we compare the Earth-to-Moon distance with the mean Earth radius, or the acceleration of a car with the acceleration of gravity *g*. Moreover, we take the opportunity to use the example on acceleration for suggesting a comparison between the performance of electric vehicles and diesel vehicles.

### Simple models are useful
Even simple models such as that of a particle with constant speed can be applied to many real cases. For example, we consider [ultrasonic distance sensor](https://nbviewer.org/github/POSS-UniMe/simple-physics-with-Python/blob/main/Chapter01/Section01/1-1-2-DistanceSensor.ipynb) for assisted parking, the measurement of the [Earth-to-Moon distance](https://nbviewer.org/github/POSS-UniMe/simple-physics-with-Python/blob/main/Chapter01/Section01/1-1-3-EarthToMoonDistance.ipynb), the time-of-flight of electromagnetic signals for [communications from Earth to the International Space Station](https://nbviewer.org/github/POSS-UniMe/simple-physics-with-Python/blob/main/Chapter01/Section01/1-1-4-LongDistanceCommunications.ipynb). We can also evaluate how long one travels in a car while reacting to some external stimulus ([reaction time](https://nbviewer.org/github/POSS-UniMe/simple-physics-with-Python/blob/main/Chapter01/Section01/1-1-1-ReactionDistance.ipynb), like a traffic light turning from green to yellow).
We also discuss the case of freely falling objects and that of a car going from 0 to 100 km/h, as examples of one-dimensional motion with constant acceleration.

In our experience, these models, usually presented at the very beginning of physics courses, are dealt with too quickly by the students (and sometimes by the instructors), with the risk of remaining unclear.


## Methods

### Jupyter Notebook as a powerful and accessible workspace to study, research, report
Thanks to the Python code cells embedded in Jupyter notebooks, the reader can change the values of some variables, and observe the effects on the other physical quantities that characterize the problem. Actually, in the examples proposed, Python scripts are used for several tasks: 
* using Python as a calculator
* computing multiple variables in a automated way
* evaluating data, reading data from a text file, writing data to a text file
* visualizing the results with plots and graphs
* saving the graphs as high-quality images in widely used formats like png, pdf, jpeg.
* analysing data, carrying out linear regression
* displaying the results as a nicely formatted table, in Markdown language or in HTML; 

Other specific advanced examples could be developed concerning:
- how to plot a graph using a selected image as background;
- how to select frames from a video
- how to get data from a video frame in order to detect the position of an object during its motion


